@@ -7,9 +7,9 @@ use warnings;
 use Data::Dmp;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-17'; # DATE
+our $DATE = '2022-10-18'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 sub meta {
     +{
@@ -80,10 +80,10 @@ sub filter {
     my $res = {};
     $res->{expr_filter} = join(
         "",
-        "do {",
-        "    my \$tmp = $dt; ",
-        @check_exprs,
-        "    else { [undef, \$tmp] } ",
+        "do {\n",
+        "  my \$tmp = $dt;\n",
+        (map { "  $_\n" } @check_exprs),
+        "  else { [undef, \$tmp] }\n",
         "}",
     );
 
@@ -105,7 +105,7 @@ Data::Sah::Filter::perl::Str::check - Perform some checks
 
 =head1 VERSION
 
-This document describes version 0.014 of Data::Sah::Filter::perl::Str::check (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
+This document describes version 0.015 of Data::Sah::Filter::perl::Str::check (from Perl distribution Data-Sah-Filter), released on 2022-10-18.
 
 =head1 SYNOPSIS
 
