@@ -5,14 +5,14 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-17'; # DATE
+our $DATE = '2022-10-18'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 sub meta {
     +{
         v => 1,
-        summary => 'Convert string to lowercase',
+        summary => 'Convert string to lowercase (synonym for lc)',
         examples => [
             {value=>'foo'},
             {value=>'Foo', filtered_value=>'foo'},
@@ -36,7 +36,7 @@ sub filter {
 }
 
 1;
-# ABSTRACT: Convert string to lowercase
+# ABSTRACT: Convert string to lowercase (synonym for lc)
 
 __END__
 
@@ -46,11 +46,11 @@ __END__
 
 =head1 NAME
 
-Data::Sah::Filter::perl::Str::downcase - Convert string to lowercase
+Data::Sah::Filter::perl::Str::downcase - Convert string to lowercase (synonym for lc)
 
 =head1 VERSION
 
-This document describes version 0.014 of Data::Sah::Filter::perl::Str::downcase (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
+This document describes version 0.015 of Data::Sah::Filter::perl::Str::downcase (from Perl distribution Data-Sah-Filter), released on 2022-10-18.
 
 =head1 SYNOPSIS
 
