@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-17'; # DATE
+our $DATE = '2022-10-18'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 sub meta {
     +{
@@ -49,7 +49,7 @@ Data::Sah::Filter::perl::Str::ltrim - Trim whitespaces at the beginning of strin
 
 =head1 VERSION
 
-This document describes version 0.014 of Data::Sah::Filter::perl::Str::ltrim (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
+This document describes version 0.015 of Data::Sah::Filter::perl::Str::ltrim (from Perl distribution Data-Sah-Filter), released on 2022-10-18.
 
 =head1 SYNOPSIS
 
@@ -79,6 +79,12 @@ This document describes version 0.014 of Data::Sah::Filter::perl::Str::ltrim (fr
 
 =for Pod::Coverage ^(meta|filter)$
 
+L<Data::Sah::Filter::perl::Str::trim>
+
+L<Data::Sah::Filter::perl::Str::rtrim>
+
+L<Data::Sah::Filter::perl::Str::remove_whitespace>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-Filter>.
