@@ -5,14 +5,14 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-17'; # DATE
+our $DATE = '2022-10-18'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 sub meta {
     +{
         v => 1,
-        summary => 'Convert string to uppercase',
+        summary => 'Convert string to uppercase (synonym for uc)',
         examples => [
             {value=>'foo', filtered_value=>'FOO'},
             {value=>'Foo', filtered_value=>'FOO'},
@@ -37,7 +37,7 @@ sub filter {
 }
 
 1;
-# ABSTRACT: Convert string to uppercase
+# ABSTRACT: Convert string to uppercase (synonym for uc)
 
 __END__
 
@@ -47,11 +47,11 @@ __END__
 
 =head1 NAME
 
-Data::Sah::Filter::perl::Str::uppercase - Convert string to uppercase
+Data::Sah::Filter::perl::Str::uppercase - Convert string to uppercase (synonym for uc)
 
 =head1 VERSION
 
-This document describes version 0.014 of Data::Sah::Filter::perl::Str::uppercase (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
+This document describes version 0.015 of Data::Sah::Filter::perl::Str::uppercase (from Perl distribution Data-Sah-Filter), released on 2022-10-18.
 
 =head1 SYNOPSIS
 
