@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-17'; # DATE
+our $DATE = '2022-10-18'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 sub meta {
     +{
@@ -62,7 +62,7 @@ Data::Sah::Filter::perl::Str::wrap - Wrap text
 
 =head1 VERSION
 
-This document describes version 0.014 of Data::Sah::Filter::perl::Str::wrap (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
+This document describes version 0.015 of Data::Sah::Filter::perl::Str::wrap (from Perl distribution Data-Sah-Filter), released on 2022-10-18.
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,10 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-F
 
 Source repository is at L<https://github.com/perlancar/perl-Data-Sah-Filter>.
 
+=head1 SEE ALSO
+
+L<Data::Sah::Filter::perl::Str::oneline>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
